@@ -296,17 +296,17 @@ extern "C" {
 # define NCO_VERSION_MINOR 5
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 1
+# define NCO_VERSION_PATCH 2
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
-# define NCO_VERSION_NOTE  "" /* May be blank */
+# define NCO_VERSION_NOTE  "" /* Blank for final versions, non-blank (e.g., "beta37") for pre-release versions */
 #endif /* !NCO_VERSION_NOTE */
 #ifndef NCO_LIB_VERSION
   /* Define NC_LIB_VERSION as three-digit number for arithmetic comparisons by CPP */
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.5.1"
+# define NCO_VERSION "4.5.2"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -881,6 +881,33 @@ extern "C" {
     nco_bool PRN_VAR_METADATA; /* [flg] Print variable metadata */
   } prn_fmt_sct;
   
+  /* Types used in regrid structure */
+  typedef enum nco_grd_2D_typ_enm{ /* [enm] Two-dimensional grid-type enum */
+    nco_grd_2D_nil=0,
+    nco_grd_2D_gss, /* Gaussian latitudes used by global spectral models: CCM 1-3, CAM 1-3, LSM, MATCH, UCICTM */
+    nco_grd_2D_fv, /* FV scalar grid (lat[0]=-90): CAM FV, GEOS-CHEM, UCICTM, UKMO */
+    nco_grd_2D_eqa, /* Equi-angle offset grid, FV staggered velocity grid (lat[0]=-89.X)): CIESIN/SEDAC, IGBP-DIS, TOMS AAI */
+    nco_grd_2D_unk, /* Unknown or unclassified, POP displaced-pole */
+  } nco_grd_2D_typ_enm;
+
+  typedef enum nco_grd_lat_typ_enm{ /* [enm] Latitude grid-type enum */
+    nco_grd_lat_nil=0,
+    nco_grd_lat_unk, /* Unknown or unclassified latitude grid type (e.g., curvilinear) */ 
+    nco_grd_lat_gss, /* Gaussian latitude grid used by global spectral models: CCM 1-3, CAM 1-3, LSM, MATCH, UCICTM */
+    nco_grd_lat_fv, /* FV latitude grid. Equi-angle (except at poles) latitude grid with odd number of latitudes so poles are considered at (and labeled as) centers of first and last gridcells (i.e., lat_ctr[0]=-90), and those polar gridcells span half the equi-angular latitude increment, aka FV scalar grid: CAM FV, GEOS-CHEM, UCICTM, UKMO */
+    nco_grd_lat_eqa, /* Equi-Angular latitude grid. Equi-angle (everywhere) latitude grid. Poles are at edges of first and last gridcells (i.e., lat_ctr[0]=-89.xxx). AKA FV-staggered velocity grid. Used by CIESIN/SEDAC, IGBP-DIS, TOMS AAI */
+  } nco_grd_lat_typ_enm;
+
+  typedef enum nco_grd_lon_typ_enm{ /* [enm] Longitude grid-type enum */
+    nco_grd_lon_nil=0,
+    nco_grd_lon_unk, /* Unknown or unclassified longitude grid type (e.g., curvilinear) */
+    nco_grd_lon_180_wst, /* Date line at west edge of first longitude cell */
+    nco_grd_lon_180_ctr, /* Date line at center of first longitude cell */
+    nco_grd_lon_Grn_wst, /* Greenwich at west edge of first longitude cell */
+    nco_grd_lon_Grn_ctr, /* Greenwich at center of first longitude cell */
+    nco_grd_lon_bb, /* Longitude grid determined by bounding box (lon_wst/lon_est) and gridcell number (lon_nbr) */
+  } nco_grd_lon_typ_enm;
+
   /* Regrid structure */
   typedef struct{ /* rgr_sct */
     // File names specifiable with individual command line switches
@@ -906,6 +933,20 @@ extern "C" {
     char *lon_nm; /* [sng] Name of dimension to recognize as longitude */
     char *lon_vrt_nm; /* [sng] Name of non-rectangular boundary variable for longitude */
     char *vrt_nm; /* [sng] Name of dimension to employ for vertices */
+    // User-specified grid properties
+    char *fl_grd; /* [sng] Name of grid file to create */
+    char *grd_ttl; /* [sng] Grid title */
+    double lat_sth; /* [dgr] Latitude of southern edge of grid */
+    double lon_wst; /* [dgr] Longitude of western edge of grid */
+    double lat_nrt; /* [dgr] Latitude of northern edge of grid */
+    double lon_est; /* [dgr] Longitude of eastern edge of grid */
+    long lat_nbr; /* [nbr] Number of latitudes in destination grid */
+    long lon_nbr; /* [nbr] Number of longitudes in destination grid */
+    nco_grd_2D_typ_enm grd_typ; /* [enm] Destination grid-type enum */
+    nco_grd_lat_typ_enm lat_typ; /* [enm] Latitude grid-type enum */
+    nco_grd_lon_typ_enm lon_typ; /* [enm] Longitude grid-type enum */
+    // Other internal data and metadata 
+    char *cmd_ln; /* [sng] Command-line */
     double wgt_vld_thr; /* [frc] Weight threshold for valid destination value */
     int in_id; /* [id] Input netCDF file ID */
     int out_id; /* [id] Output netCDF file ID */
@@ -913,6 +954,7 @@ extern "C" {
     nco_bool flg_usr_rqs; /* [flg] User requested regridding */
     nco_bool flg_grd_src; /* [flg] User-specified input grid */
     nco_bool flg_grd_dst; /* [flg] User-specified destination grid */
+    nco_bool flg_grd; /* [flg] Create SCRIP-format grid file */
     nco_bool flg_map; /* [flg] User-specified mapping weights */
     nco_bool flg_rnr; /* [flg] Renormalize destination values by valid area */
   } rgr_sct;
@@ -1217,6 +1259,8 @@ extern "C" {
     char *nm; /* [sng] Variable name */
     char *nm_fll; /* [sng] Absolute variable name (needed for GTT search for object by full name) */
     char fmt[5]; /* [sng] Hint for printf()-style formatting */
+    double *wgt_sum; /* [frc] Running sum of per-file weights (ncra/ncea only) */
+    double wgt_crr; /* [frc] Weight of current record (ncra/ncea only) */
     dmn_sct **dim; /* [sct] Pointers to full dimension structures */
     int *dmn_id; /* [id] Contiguous vector of dimension IDs */
     int cid; /* [id] Dimension ID of associated coordinate, if any */
