@@ -127,16 +127,16 @@ extern "C" {
   
   kvm_sct /* O [sct] Key-value pair */
   nco_sng2kvm /* [fnc] Parse string into key-value pair */
-  (char *sng, /* I [sng] String to parse, including "=" */
-   kvm_sct kvm); /* O [sct] Key-value pair */
+  (char *sng); /* I [sng] String to parse, including "=" */
   
   char * /* O [sng] Stripped-string */
   nco_sng_strip /* [fnc] Strip leading and trailing white space */
   (char *sng); /* I/O [sng] String to strip */
   
-  void
-  nco_kvm_free /* [fnc] Relinquish dynamic memory from list of kvm structures */
-  (kvm_sct *kvm); /* I/O [sct] List of kvm structures */
+  kvm_sct * /* O [sct] Pointer to free'd kvm list */
+  nco_kvm_lst_free /* [fnc] Relinquish dynamic memory from list of kvm structures */
+  (kvm_sct *kvm, /* I/O [sct] List of kvm structures */
+   const int kvm_nbr); /* I [nbr] Number of kvm structures */
   
   void
   nco_kvm_prn /* [fnc] Print kvm contents */
